@@ -50,6 +50,18 @@ class BlockInterfaceField(object):
 		self.fieldType = self.FTYPE_UNKNOWN
 		self.initialValue = initialValue
 
+	def __repr__(self):
+		ftype = {
+			self.FTYPE_UNKNOWN	: "UNKNOWN",
+			self.FTYPE_IN		: "IN",
+			self.FTYPE_OUT		: "OUT",
+			self.FTYPE_INOUT	: "IN_OUT",
+			self.FTYPE_STAT		: "STAT",
+			self.FTYPE_TEMP		: "TEMP",
+		}[self.fieldType]
+		return "(%s)  %s : %s" %\
+			(ftype, self.name, str(self.dataType))
+
 class BlockInterface(object):
 	# Data-types that must be passed "by-reference" to FCs/FBs.
 	callByRef_Types = (
@@ -91,6 +103,12 @@ class BlockInterface(object):
 		ret.extend(self.fields_INOUT)
 		return ret
 
+	@property
+	def fields_IN_OUT_INOUT_STAT(self):
+		ret = self.fields_IN_OUT_INOUT # don't copy
+		ret.extend(self.fields_STAT)
+		return ret
+
 	def __addField(self, field):
 		if field.name in self.fieldNameMap:
 			raise AwlSimError("Data structure field name '%s' is ambiguous." %\
