@@ -43,35 +43,48 @@ class AwlParamAssign(object):
 
 	# Re-assign the isInbound() and isOutbound() methods
 	# to methods return static values.
-	def __reassignMethods(self, interface):
+	def __reassignInboundOutboundMethods(self, interface):
 		self.isInbound, self.isOutbound = self.__retFalse, self.__retFalse
 		field = interface.getFieldByName(self.lvalueName)
-		if field.fieldType == BlockInterface.Field.FTYPE_IN or\
-		   field.fieldType == BlockInterface.Field.FTYPE_INOUT:
+		if field.fieldType == BlockInterfaceField.FTYPE_IN or\
+		   field.fieldType == BlockInterfaceField.FTYPE_INOUT:
 			self.isInbound = self.__retTrue
-		if field.fieldType == BlockInterface.Field.FTYPE_OUT or\
-		   field.fieldType == BlockInterface.Field.FTYPE_INOUT:
+		if field.fieldType == BlockInterfaceField.FTYPE_OUT or\
+		   field.fieldType == BlockInterfaceField.FTYPE_INOUT:
 			self.isOutbound = self.__retTrue
 
 	def isInbound(self, interface):
-		self.__reassignMethods(interface)
+		self.__reassignInboundOutboundMethods(interface)
 		# Call the re-assigned method
 		return self.isInbound(None)
 
 	def isOutbound(self, interface):
-		self.__reassignMethods(interface)
+		self.__reassignInboundOutboundMethods(interface)
 		# Call the re-assigned method
 		return self.isOutbound(None)
 
-	def __getLvalueStructField_static(self, interfaceDB):
+	def __getLvalueStructField_static(self, instanceDB):
 		return self.__LvaluestructField
 
 	# Get the AwlStructField corresponding to this parameter lvalue
-	def getLvalueStructField(self, interfaceDB):
-		self.__LvaluestructField = interfaceDB.structInstance.struct.getField(self.lvalueName)
+	def getLvalueStructField(self, instanceDB):
+		# Find the l-value struct field
+		self.__LvaluestructField = instanceDB.structInstance.struct.getField(self.lvalueName)
+		# Re-assign this method to return the found and stored static value.
 		self.getLvalueStructField = self.__getLvalueStructField_static
 		# Call the re-assigned method
 		return self.getLvalueStructField(None)
 
+	def __getInterfaceFieldIndex_static(self, interface):
+		return self.__LvalueInterfIndex
+
+	def getInterfaceFieldIndex(self, interface):
+		# Find the index number for the l-value
+		self.__LvalueInterfIndex = interface.getFieldIndex(self.lvalueName)
+		# Re-assign this method to return the found and stored static index value.
+		self.getInterfaceFieldIndex = self.__getInterfaceFieldIndex_static
+		# Call the re-assigned method
+		return self.getInterfaceFieldIndex(None)
+
 	def __repr__(self):
 		return "%s := %s" % (self.lvalueName, str(self.rvalueOp))
