@@ -26,6 +26,7 @@ from awlsim.core.util import *
 
 
 class MemoryArea(object):
+	# Possible memType values
 	EnumGen.start
 	TYPE_E		= EnumGen.item # input memory
 	TYPE_A		= EnumGen.item # output memory
@@ -37,7 +38,11 @@ class MemoryArea(object):
 	TYPE_STW	= EnumGen.item # status word
 	EnumGen.end
 
-	def __init__(self, memType, flags, index, start, length, data=None):
+	# Possible flags
+	FLG_ERR_READ	= 0x01
+	FLG_ERR_WRITE	= 0x02
+
+	def __init__(self, memType, flags, index, start, length, data=b''):
 		self.memType = memType
 		self.flags = flags
 		self.index = index
@@ -45,56 +50,103 @@ class MemoryArea(object):
 		self.length = length
 		self.data = data
 
+	def __raiseReadErr(self, exception):
+		self.flags |= self.FLG_ERR_READ
+		raise exception
+
+	def __raiseWriteErr(self, exception):
+		self.flags |= self.FLG_ERR_WRITE
+		raise exception
+
 	def __read_E(self, cpu):
-		self.data = cpu.inputs[self.start : self.start + self.length]
+		end = self.start + self.length
+		if end > len(cpu.inputs):
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Read range error")
+			)
+		self.data = bytes(cpu.inputs[self.start : end])
 
 	def __read_A(self, cpu):
-		self.data = cpu.outputs[self.start : self.start + self.length]
+		end = self.start + self.length
+		if end > len(cpu.outputs):
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Read range error")
+			)
+		self.data = bytes(cpu.outputs[self.start : end])
 
 	def __read_M(self, cpu):
-		self.data = cpu.flags[self.start : self.start + self.length]
+		end = self.start + self.length
+		if end > len(cpu.flags):
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Read range error")
+			)
+		self.data = bytes(cpu.flags[self.start : end])
 
 	def __read_L(self, cpu):
-		self.data = cpu.callStackTop.localdata[self.start : self.start + self.length]
+		localdata = cpu.callStackTop.localdata
+		end = self.start + self.length
+		if end > len(localdata):
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Read range error")
+			)
+		self.data = bytes(localdata[self.start : end])
 
 	def __read_DB(self, cpu):
 		try:
 			db = cpu.dbs[self.index]
 		except KeyError:
-			raise AwlSimError("MemoryArea: Read access to "
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Read access to "
 				"nonexistent DB %d" % self.index)
+			)
 		if not (db.permissions & db.PERM_READ):
-			raise AwlSimError("MemoryArea: Read access to "
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Read access to "
 				"read-protected DB %d" % self.index)
-		self.data = db.structInstance.dataBytes[self.start : self.start + self.length]
+			)
+		dataBytes = db.structInstance.dataBytes
+		end = self.start + self.length
+		if end > len(dataBytes):
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Read range error")
+			)
+		self.data = bytes(dataBytes[self.start : end])
 
 	def __read_T(self, cpu):
 		try:
 			timer = cpu.timers[self.index]
 		except IndexError as e:
-			raise AwlSimError("MemoryArea: Invalid timer index %d" % self.index)
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Invalid timer index %d" % self.index)
+			)
 		if self.start == 1:
 			self.data, self.length = b'\x01' if timerget() else b'\x00', 1
 		elif self.start == 16:
 			v = timer.getTimevalBin()
 			self.data, self.length = bytes(((v >> 8) & 0xFF, v & 0xFF)), 2
 		else:
-			raise AwlSimError("MemoryArea: Invalid start=%d in timer read. "
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Invalid start=%d in timer read. "
 				"Must be 1 or 16." % self.start)
+			)
 
 	def __read_Z(self, cpu):
 		try:
 			counter = cpu.timers[self.index]
 		except IndexError as e:
-			raise AwlSimError("MemoryArea: Invalid counter index %d" % self.index)
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Invalid counter index %d" % self.index)
+			)
 		if self.start == 1:
 			self.data, self.length = b'\x01' if counter.get() else b'\x00', 1
 		elif self.start == 16:
 			v = counter.getValueBin()
 			self.data, self.length = bytes(((v >> 8) & 0xFF, v & 0xFF)), 2
 		else:
-			raise AwlSimError("MemoryArea: Invalid start=%d in counter read. "
+			self.__raiseReadErr(
+				AwlSimError("MemoryArea: Invalid start=%d in counter read. "
 				"Must be 1 or 16." % self.start)
+			)
 
 	def __read_STW(self, cpu):
 		stw = cpu.statusWord.getWord()
@@ -112,24 +164,49 @@ class MemoryArea(object):
 	}
 
 	def __write_E(self, cpu):
-		cpu.inputs[self.start : self.start + self.length] = self.data
+		end = self.start + self.length
+		if end > len(cpu.inputs):
+			self.__raiseWriteErr(
+				AwlSimError("MemoryArea: Write range error")
+			)
+		cpu.inputs[self.start : end] = self.data
 
 	def __write_A(self, cpu):
-		cpu.outputs[self.start : self.start + self.length] = self.data
+		end = self.start + self.length
+		if end > len(cpu.outputs):
+			self.__raiseWriteErr(
+				AwlSimError("MemoryArea: Write range error")
+			)
+		cpu.outputs[self.start : end] = self.data
 
 	def __write_M(self, cpu):
-		cpu.flags[self.start : self.start + self.length] = self.data
+		end = self.start + self.length
+		if end > len(cpu.flags):
+			self.__raiseWriteErr(
+				AwlSimError("MemoryArea: Write range error")
+			)
+		cpu.flags[self.start : end] = self.data
 
 	def __write_DB(self, cpu):
 		try:
 			db = cpu.dbs[self.index]
 		except KeyError:
-			raise AwlSimError("MemoryArea: Write access to "
+			self.__raiseWriteErr(
+				AwlSimError("MemoryArea: Write access to "
 				"nonexistent DB %d" % self.index)
+			)
 		if not (db.permissions & db.PERM_WRITE):
-			raise AwlSimError("MemoryArea: Write access to "
+			self.__raiseWriteErr(
+				AwlSimError("MemoryArea: Write access to "
 				"write-protected DB %d" % self.index)
-		db.structInstance.dataBytes[self.start : self.start + self.length] = self.data
+			)
+		dataBytes = db.structInstance.dataBytes
+		end = self.start + self.length
+		if end > len(dataBytes):
+			self.__raiseWriteErr(
+				AwlSimError("MemoryArea: Write range error")
+			)
+		dataBytes[self.start : end] = self.data
 
 	__writeHandlers = {
 		TYPE_E		: __write_E,
@@ -142,19 +219,27 @@ class MemoryArea(object):
 		try:
 			self.__readHandlers[self.memType](self, cpu)
 		except KeyError:
-			raise AwlSimError("Invalid MemoryArea memType %d "
+			self.__raiseReadErr(
+				AwlSimError("Invalid MemoryArea memType %d "
 				"in read operation" % self.memType)
+			)
 		except (IndexError, TypeError) as e:
-			raise AwlSimError("Invalid MemoryArea read")
+			self.__raiseReadErr(
+				AwlSimError("Invalid MemoryArea read")
+			)
 
 	def writeToCpu(self, cpu):
 		try:
 			self.__writeHandlers[self.memType](self, cpu)
 		except KeyError:
-			raise AwlSimError("Invalid MemoryArea memType %d "
+			self.__raiseWriteErr(
+				AwlSimError("Invalid MemoryArea memType %d "
 				"in write operation" % self.memType)
+			)
 		except (IndexError, TypeError) as e:
-			raise AwlSimError("Invalid MemoryArea write")
+			self.__raiseWriteErr(
+				AwlSimError("Invalid MemoryArea write")
+			)
 
 	# Check whether another area overlaps with this one.
 	# Doesn't compare the flags.
